@@ -38,12 +38,11 @@ menu <- function(choices,
       selected = selected,
       return_index = return_index
     ))
-  } else {
-    return(select(
-      choices = choices,
-      prompt = prompt,
-      selected = selected,
-      return_index = return_index
-    ))
   }
+  select(
+    choices = choices,
+    prompt = prompt,
+    selected = selected,
+    return_index = return_index
+  )
 }
